@@ -3,7 +3,7 @@ import time
 
 from ats_base.common import func
 from ats_base.log.logger import logger
-from ats_base.service import app, pro, udm
+from ats_base.service import app, pro, udm, mm
 
 from ats_case.case.context import Context
 from ats_case.common.enum import ProClazz, OperationClazz
@@ -106,6 +106,10 @@ def _replace(context: Context, data: dict):
         else:
             sd = sd.replace('\'#{}\''.format(r), str(v))
 
+    re_list = re.findall(r"&(.+?)\'", sd)
+    for r in re_list:
+        sd = sd.replace(r, '{}:{}:{}:{}'.format(context.test_sn, context.case.id, context.meter.pos, r))
+
     return eval(sd)
 
 
@@ -151,7 +155,7 @@ class Meter(object):
         self._operation = key
         return self
 
-    def element(self, di: str):
+    def element(self, di):
         self._element = di
         return self
 
@@ -190,10 +194,10 @@ class Meter(object):
         return self
 
     def acv(self):
-        logger.info('~ @ACD-HANDLE-> module:{} function:{} parameter:{}'.format(
+        logger.info('~ @ACD-> module:{} function:{} parameter:{}'.format(
             self._func_module, self._func, self._func_parameter))
-        result = udm.acv(module=self._func_module, function=self._func, data=self._func_parameter)
-        logger.info('~ @ACD-HANDLE<- module:{} function:{} result:{}'.format(self._func_module, self._func, result))
+        result = udm.acv(module='meter.{}'.format(self._func_module), function=self._func, data=self._func_parameter)
+        logger.info('~ @ACD<- module:{} function:{} result:{}'.format(self._func_module, self._func, result))
 
         return result
 
@@ -205,8 +209,7 @@ class Meter(object):
 
         self._frame = result.get('result')
 
-        self._func_parameter['return_result'] = self.decode()
-
+        self._func_parameter['result'] = self.decode()
         self._func_parameter = _replace(context, self._func_parameter)
 
         send(context, todo={'app:show': {'msg': self.acv()}})
@@ -252,6 +255,7 @@ class Bench(object):
         self._parameter = None
         self._function = None
         self._interval = None
+        self._cache = None
         self._result = None
         self._exec_times = 0
         self._sleep = 0
@@ -276,6 +280,10 @@ class Bench(object):
         self._interval = times
         return self
 
+    def cache(self, data):
+        self._cache = data
+        return self
+
     def encode(self, context: Context):
         logger.info(
             '~ @BENCH-> manufacture:{} operation:{} parameter:{}'.format(self._manufacture, self._operation,
@@ -284,11 +292,22 @@ class Bench(object):
         if self._function is not None and len(self._function) > 0:
             self._built_in(context)
 
-    def decode(self):
+    def decode(self, context: Context):
         logger.info('~ @BENCH<- manufacture:{} operation:{} result:{}'.format(self._manufacture,
                                                                               self._operation, self._result))
 
         self._result = {'result': self._result.get('result')}
+        self._flush(context)
+
+    def _built_in(self, context: Context):
+        logger.info('~ @BUILTIN-> module:{} parameter:{}'.format('bench', self._parameter))
+        for op, d in self._function.items():
+            v_data = udm.built_in(module='bench', function=op, data=func.to_dict(
+                param=d, iabc=context.meter.iabc, voltage=context.meter.rated_voltage,
+                current=context.meter.rated_current, index=self._exec_times))
+            self._parameter = _replace_u(self._parameter, v_data)
+
+        logger.info('~ @BUILTIN<- module:{} parameter:{}'.format('bench', self._parameter))
 
     def acv(self):
         logger.info('~ @ACD-> module:{} function:{} parameter:{}'.format(
@@ -298,15 +317,10 @@ class Bench(object):
 
         return result
 
-    def _built_in(self, context: Context):
-        logger.info('~ @BUILTIN-> module:{} parameter:{}'.format('bench', self._parameter))
-        for op, d in self._function.items():
-            v_data = udm.built_in(module='bench', function=op, data=func.to_dict(
-                param=d, iabc=context.meter.iabc, voltage=context.meter.rated_voltage,
-                current=context.meter.rated_current, times=self._exec_times))
-            self._parameter = _replace_u(self._parameter, v_data)
-
-        logger.info('~ @BUILTIN<- module:{} parameter:{}'.format('bench', self._parameter))
+    def _flush(self, context: Context):
+        if self._cache is not None:
+            self._cache = '{}:{}:{}:{}'.format(context.test_sn, context.case.id, context.meter.pos, self._cache)
+            mm.put(self._cache, self._result.get('result'))
 
     def rest(self, context: Context):
         if self._sleep > 0:
@@ -325,7 +339,7 @@ class Bench(object):
 
         self.encode(context)
         self._result = send(context, todo={'bench:{}'.format(self._operation): self._parameter})
-        self.decode()
+        self.decode(context)
 
         send(context, todo={'app:show': {'msg': self.acv()}})
 
@@ -405,4 +419,5 @@ class ATS(object):
 
 if __name__ == '__main__':
     import math
-    print(math.floor(3/4))
\ No newline at end of file
+
+    print(math.floor(3 / 4))
