@@ -95,7 +95,6 @@ class METER(Operation):
         clazz = op.get('clazz')
         opt = op.get('operation')
         elem = op.get('element')
-        elem_list = op.get('element_list')
         param = op.get('parameter')
         acd = op.get('acd')
 
@@ -104,8 +103,6 @@ class METER(Operation):
 
         if elem is not None:
             code += ".element('{}')".format(elem)
-        if elem_list is not None:
-            code += ".element_list('{}')".format(elem_list)
         if param is not None:
             code += ".parameter({})".format(param)
         if acd is not None:
@@ -124,6 +121,7 @@ class BENCH(Operation):
         function = op.get('function')
         sleep = op.get('sleep')
         interval = op.get('interval')
+        cache = op.get('cache')
 
         code = "command.bench('{}').operation('{}')".format(clazz, opt)
 
@@ -135,6 +133,8 @@ class BENCH(Operation):
             code += ".sleep({})".format(sleep)
         if interval is not None:
             code += ".interval({})".format(interval)
+        if cache is not None:
+            cache += ".cache({})".format(cache)
 
         code += ".exec(context)"
 
